@@ -56,6 +56,7 @@
 #define LABEL_DUMMY "DUMMY"
 #define LABEL_GFX_GAME "GFX_GAME"
 #define LABEL_GFX_MENU "GFX_MENU"
+#define LABEL_FULLSCREEN "FULLSCREEN"
 #define LABEL_VIEWPORT_SIZE "VIEWPORT_SIZE"
 #define LABEL_WAVE_NUMBER "WAVE_NUMBER"
 #define LABEL_WAVE_AMPLI "WAVE_AMPLI"
@@ -96,6 +97,7 @@
 
 int CONFIG_GFX_GAME;
 int CONFIG_GFX_MENU;
+int CONFIG_FULLSCREEN;
 int CONFIG_VIEWPORT_SIZE;
 int CONFIG_WAVE_NUMBER[4];
 int CONFIG_WAVE_AMPLI[4];
@@ -157,6 +159,7 @@ void load_default_options (void)
  CONFIG_GFX_GAME=2;
  CONFIG_GFX_MENU=2;
 #endif
+ CONFIG_FULLSCREEN=1;
  CONFIG_VIEWPORT_SIZE=5;
  
  CONFIG_WAVE_NUMBER[0]=2;
@@ -261,6 +264,7 @@ static int load_disk_options (void)
     {
 	CONFIG_GFX_GAME=get_config_int(LABEL_MAIN,LABEL_GFX_GAME,CONFIG_GFX_GAME);
 	CONFIG_GFX_MENU=get_config_int(LABEL_MAIN,LABEL_GFX_MENU,CONFIG_GFX_MENU);
+	CONFIG_FULLSCREEN=get_config_int(LABEL_MAIN,LABEL_FULLSCREEN,CONFIG_FULLSCREEN);
 	CONFIG_VIEWPORT_SIZE=get_config_int(LABEL_MAIN,LABEL_VIEWPORT_SIZE,CONFIG_VIEWPORT_SIZE);
 
 	for (i=0;i<4;++i){
@@ -349,6 +353,7 @@ int save_config_options (void)
 
 	set_config_int(LABEL_MAIN,LABEL_GFX_GAME,CONFIG_GFX_GAME);
 	set_config_int(LABEL_MAIN,LABEL_GFX_MENU,CONFIG_GFX_MENU);
+	set_config_int(LABEL_MAIN,LABEL_FULLSCREEN,CONFIG_FULLSCREEN);
 	set_config_int(LABEL_MAIN,LABEL_VIEWPORT_SIZE,CONFIG_VIEWPORT_SIZE);
 
 	for (i=0;i<4;++i){
