@@ -104,7 +104,7 @@ int error_graphics_init_failed (void)
 /*------------------------------------------------------------------*/
 int error_no_network_support (void)
 {
- return (standard_error("No network support"));
+ return (standard_error("No network support for this platform. Only Windows and UNIX have it."));
 }
 
 /*------------------------------------------------------------------*/
