@@ -66,7 +66,8 @@ static void exit_all (void)
  #ifdef ALLEGRO_DOS
  set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
  #endif
- log_println_str ("Leaving Allegro by Shawn Hargreaves.");
+ log_println();
+ log_println_str ("Leaving Allegro (http://www.talula.demon.co.uk/allegro)");
  save_config_options ();
  stop_water();
  stop_ticker();
@@ -86,7 +87,7 @@ static void disp_base_message (void)
  log_println_str("This release compiled on " __DATE__ ".");
  log_println();
  log_println_str("E-mail    : ufoot@ufoot.org");
- log_println_str("Web       : http://www.ufoot.org/liquidwar/");
+ log_println_str("Web       : http://www.ufoot.org");
  log_println_str("Address   : Christian Mauduit");
  log_println_str("            8 Allee de la Fresnaie");
  log_println_str("            95120 Ermont FRANCE");
@@ -97,7 +98,7 @@ static void disp_base_message (void)
  log_println_str("Liquid War should stay free software for ever.");
  log_println_str("I am NOT responsible for any damage caused by this software.");
  log_println();
- log_println_str("Check out http://www.ufoot.org for complete information.");
+ log_println_str("Check out http://www.ufoot.org/liquidwar for complete information.");
 }
 
 /*------------------------------------------------------------------*/
