@@ -36,7 +36,9 @@
 
 #include <allegro.h>
 
+#include "base.h"
 #include "disk.h"
+#include "log.h"
 #include "gfxmode.h"
 #include "startup.h"
 
@@ -65,76 +67,120 @@ int GFX_MODE_H[5]={240,384,480,600,768};
 
 /*------------------------------------------------------------------*/
 int need_to_change_mode(int res1,int res2,int flip){
-	if (res1==res2 && !flip)
-		return 0;
-	else
-		return !0;
+  if (res1==res2 && !flip)
+    return 0;
+  else
+    return !0;
 }
 
 /*------------------------------------------------------------------*/
-int set_resolution (int res, int flip)
+int set_resolution (int res, int flip, int fullscreen)
 {
- int ret=1;
- int num_try;
- int nb_try;
+  int ret=1;
+  int num_try;
+  int nb_try;
 
 #ifdef ALLEGRO_DOS
- static int GFX_MODE_TYPE[]={GFX_MODEX,
-			     GFX_MODEX,
-			     GFX_AUTODETECT,
-			     GFX_AUTODETECT,
-			     GFX_AUTODETECT};
+  static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_MODEX,
+					 GFX_MODEX,
+					 GFX_VESA2L,
+					 GFX_VESA2L,
+					 GFX_VESA2L};
+  static int GFX_MODE_TYPE_WINDOWED[]={GFX_MODEX,
+				       GFX_MODEX,
+				       GFX_VESA2L,
+				       GFX_VESA2L,
+				       GFX_VESA2L};
 #endif
 
 #ifdef ALLEGRO_WINDOWS
-	static int GFX_MODE_TYPE[]={GFX_AUTODETECT,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT};
+  static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_DIRECTX,
+					 GFX_DIRECTX,
+					 GFX_DIRECTX,
+					 GFX_DIRECTX,
+					 GFX_DIRECTX};
+  static int GFX_MODE_TYPE_WINDOWED[]={GFX_DIRECTX_WIN,
+				       GFX_DIRECTX_WIN,
+				       GFX_DIRECTX_WIN,
+				       GFX_DIRECTX_WIN,
+				       GFX_DIRECTX_WIN};
 #endif
 
 #ifdef ALLEGRO_UNIX
-	static int GFX_MODE_TYPE[]={GFX_AUTODETECT,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT};
+  static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_AUTODETECT_FULLSCREEN,
+					 GFX_AUTODETECT_FULLSCREEN,
+					 GFX_AUTODETECT_FULLSCREEN,
+					 GFX_AUTODETECT_FULLSCREEN,
+					 GFX_AUTODETECT_FULLSCREEN};
+  static int GFX_MODE_TYPE_WINDOWED[]={GFX_AUTODETECT_WINDOWED,
+				       GFX_AUTODETECT_WINDOWED,
+				       GFX_AUTODETECT_WINDOWED,
+				       GFX_AUTODETECT_WINDOWED,
+				       GFX_AUTODETECT_WINDOWED};
 #endif
 
- nb_try=0;
- while (nb_try<5 && ret){
- if (nb_try==0)
-	num_try=res;
- else
-	 num_try=nb_try-1;
- nb_try++;
- ret=set_gfx_mode(	GFX_MODE_TYPE[num_try],
-					GFX_MODE_W[num_try],
-					GFX_MODE_H[num_try],
-					GFX_MODE_W[num_try],
-					flip 
-					?	GFX_MODE_H[num_try]*2
-					:	GFX_MODE_H[num_try]);
- }
+  int w1,h1,w2,h2;
 
- if (!ret)
+  log_print_str("Changing video mode to ");
+  log_print_int(GFX_MODE_W[res]);
+  log_print_str("x");
+  log_print_int(GFX_MODE_H[res]);
+  if (fullscreen)
+    log_print_str(", fullscreen");
+  else
+    log_print_str(", windowed");
+  if (flip)
+    log_print_str(", page flipping enabled");
+  log_println_str(".");
+
+  nb_try=0;
+  while (nb_try<5 && ret){
+    if (nb_try==0)
+      num_try=res;
+    else
+      num_try=nb_try-1;
+    nb_try++;
+
+    w1 = GFX_MODE_W[num_try];
+    h1 = GFX_MODE_H[num_try];
+    w2 = GFX_MODE_W[num_try];
+    h2 = flip ? GFX_MODE_H[num_try]*2 : GFX_MODE_H[num_try];
+
+    /*
+     * First try, we try the "prefered" driver
+     */
+    if (fullscreen)
+      ret=set_gfx_mode(GFX_MODE_TYPE_FULLSCREEN[num_try],w1,h1,w2,h2);
+    else
+      ret=set_gfx_mode(GFX_MODE_TYPE_WINDOWED[num_try],w1,h1,w2,h2);
+    if (ret)
+      {
+	/*
+	 * Second try, we try Allegro's default driver
+	 */
+	ret=set_gfx_mode(GFX_AUTODETECT,w1,h1,w2,h2);
+      }
+  }
+
+  if (!ret)
     {
-     set_palette( black_palette);
+      set_palette(black_palette);
 
-     if (SCREEN_W>=640)
+      if (SCREEN_W>=640)
         {
-         font=BIG_FONT;
-         set_mouse_sprite (BIG_MOUSE_CURSOR);
+	  font=BIG_FONT;
+	  set_mouse_sprite (BIG_MOUSE_CURSOR);
         }
-     else
-         {
+      else
+	{
           font=SMALL_FONT;
           set_mouse_sprite (SMALL_MOUSE_CURSOR);
-         }
+	}
+      
+      set_window_title("Liquid War " LW_VERSION);
     }
 
- return (ret);
+  return (ret);
 }
 
 
