@@ -49,6 +49,6 @@ extern int GFX_MODE_H[5];
 /*==================================================================*/
 
 int need_to_change_mode(int res1,int res2,int flip);
-int set_resolution (int, int);
+int set_resolution (int res, int flip, int fullscreen);
 
 #endif
