@@ -97,6 +97,15 @@ static char *get_page_flip_str(void)
     return ("Off");
 }
 
+/*------------------------------------------------------------------*/
+static char *get_fullscreen_str(void)
+{
+  if (CONFIG_FULLSCREEN)
+    return ("Fullscreen");
+  else
+    return ("Windowed");
+}
+
 /*------------------------------------------------------------------*/
 static int slider_game_res (void *dp3, int d2)
 {
@@ -142,77 +151,90 @@ int graphic_options (void)
   /* la gestion des paramtres curseur a ete mise en commentaire...*/
 
   int menu_res_changed=0;
+  int fullscreen_changed=0;
   int game_res_changed=0;
   DIALOG_PLAYER *dp;
-  DIALOG d[18];
+  DIALOG d[20];
   int i,choix=4,retour=0;
-  static int y_pos[6]={0,2,3,4,5,7};
+  static int y_pos[7]={0,1,3,4,5,6,8};
   int *temp;
 
   display_back_image();
   while (retour==0)
     {
-      for (i=0; i<6; ++i)
+      for (i=0; i<7; ++i)
 	{
-	  standard_button (d+i+4,0,y_pos[i],2,9);
+	  standard_button (d+i+4,0,y_pos[i],2,10);
 	  d[i+4].proc=my_textbox_proc;
 	}
-      for (i=0; i<6; ++i)
+      for (i=0; i<7; ++i)
 	{
-	  standard_button (d+i+10,1,y_pos[i],2,9);
-	  d[i+10].proc=my_slider_proc;
+	  standard_button (d+i+11,1,y_pos[i],2,10);
+	  d[i+11].proc=my_slider_proc;
 	}
 
-      standard_button (d+16,0,8,1,9);
-      d[16].dp="Advanced";
+      standard_button (d+18,0,9,1,10);
+      d[18].dp="Advanced";
 
       quick_buttons(d);
-      d[4].dp="Brightness";
-      d[5].dp=get_menu_res_str();
-      d[6].dp=get_game_res_str();
-      d[7].dp="Viewport size";
-      d[8].dp="Page flipping";
-      d[9].dp="Waves (F4)";
-      d[10].dp=d[11].dp=d[12].dp=d[13].dp=d[14].dp=d[15].dp=NULL;
-      //#ifdef ALLEGRO_WINDOWS  
-      //d[11].flags=D_HIDDEN;
-      //#endif
-      d[10].d1=16;
-      d[11].d1=d[12].d1=4;
-      d[13].d1=8;
-      d[14].d1=8;
-      d[13].dp3=&CONFIG_VIEWPORT_SIZE;
-      for (i=13;i<14;++i)
+      d[4].dp="Video mode";
+      d[5].dp="Brightness";
+      d[6].dp=get_menu_res_str();
+      d[7].dp=get_game_res_str();
+      d[8].dp="Viewport size";
+      d[9].dp="Page flipping";
+      d[10].dp="Waves (F4)";
+      d[11].dp=d[12].dp=d[13].dp=d[14].dp=d[15].dp=d[16].dp=d[17].dp=NULL;
+      d[12].d1=18;
+      d[13].d1=d[14].d1=4;
+      d[15].d1=8;
+      d[16].d1=8;
+      d[15].dp3=&CONFIG_VIEWPORT_SIZE;
+      for (i=15;i<16;++i)
 	{
 	  d[i].dp=NULL;
 	  d[i].dp2=slider_int;
 	  temp=d[i].dp3;
 	  d[i].d2=*temp;
 	}
-      d[10].dp=d[11].dp=d[12].dp=NULL;
-      d[10].d2=CONFIG_BRIGHTNESS;
-      d[11].d2=CONFIG_GFX_MENU;
-      d[12].d2=CONFIG_GFX_GAME;
-      d[10].dp2=slider_brightness;
-      d[11].dp2=slider_menu_res;
-      d[12].dp2=slider_game_res;
-      d[11].dp3=&menu_res_changed;
-      d[12].dp3=&game_res_changed;
+      d[12].dp=d[13].dp=d[14].dp=NULL;
+      d[12].d2=CONFIG_BRIGHTNESS;
+      d[13].d2=CONFIG_GFX_MENU;
+      d[14].d2=CONFIG_GFX_GAME;
+      d[12].dp2=slider_brightness;
+      d[13].dp2=slider_menu_res;
+      d[14].dp2=slider_game_res;
+      d[13].dp3=&menu_res_changed;
+      d[14].dp3=&game_res_changed;
 
-      d[14].proc=my_button_proc;
-      d[14].dp=get_page_flip_str();
-      d[14].flags=D_EXIT;
+      d[11].proc=my_button_proc;
+      d[11].dp=get_fullscreen_str();
+#ifdef ALLEGRO_DOS
+      /*
+       * Under DOS, fullscreen or windowed makes no sense, so we simply
+       * remove the button to avoid confusion.
+       */
+      d[4].flags|=D_HIDDEN;
+      d[11].flags=D_EXIT|D_HIDDEN;
+#else
+      d[11].flags=D_EXIT;
+#endif
 
-      d[15].proc=my_button_proc;
-      d[15].dp=get_wave_mode_str();
-      d[15].flags=D_EXIT;
+      d[16].proc=my_button_proc;
+      d[16].dp=get_page_flip_str();
+      d[16].flags=D_EXIT;
 
-      d[17].proc=0;
+      d[17].proc=my_button_proc;
+      d[17].dp=get_wave_mode_str();
+      d[17].flags=D_EXIT;
+
+      d[19].proc=0;
 
       game_res_changed=0;
-      if (menu_res_changed)
+      if (menu_res_changed || fullscreen_changed)
 	{
 	  menu_res_changed=0;
+	  fullscreen_changed=0;
 	  display_back_image ();
 	  dp=init_dialog (d,choix);
 	  my_fade_in ();
@@ -230,22 +252,22 @@ int graphic_options (void)
 
       if (menu_res_changed)
 	{
-	  if (d[11].d2!=CONFIG_GFX_MENU)
+	  if (d[13].d2!=CONFIG_GFX_MENU)
 	    {
 	      my_fade_out ();
-	      if (set_resolution (d[11].d2,0))
+	      if (set_resolution (d[13].d2,0,CONFIG_FULLSCREEN))
 		CONFIG_GFX_MENU=0;
 	      else
-		CONFIG_GFX_MENU=d[11].d2;
+		CONFIG_GFX_MENU=d[13].d2;
 	    }
-	  d[11].dp=get_menu_res_str();
+	  d[13].dp=get_menu_res_str();
 	}
       else
 	{
 	  if (game_res_changed)
 	    {
-	      CONFIG_GFX_GAME=d[12].d2;
-	      d[12].dp=get_game_res_str();
+	      CONFIG_GFX_GAME=d[14].d2;
+	      d[14].dp=get_game_res_str();
 	      retour=0;
 	    }
 	  else
@@ -270,17 +292,25 @@ int graphic_options (void)
 		  retour=display_help (HELP_TEXT_GRAPHICS);
 		  display_back_image ();
 		  break;
-		case 14:
-		  CONFIG_PAGE_FLIP=CONFIG_PAGE_FLIP ? 0 : 1;
-		  d[14].dp=get_page_flip_str();
-		  my_button_proc (MSG_DRAW,d+14,0);
-		  break;
-		case 15:
-		  CONFIG_WAVE_ON=CONFIG_WAVE_ON ? 0 : 1;
-		  d[15].dp=get_wave_mode_str();
-		  my_button_proc (MSG_DRAW,d+15,0);
+		case 11:
+		  CONFIG_FULLSCREEN=CONFIG_FULLSCREEN ? 0 : 1;
+		  d[11].dp=get_fullscreen_str();
+		  my_button_proc (MSG_DRAW,d+11,0);
+		  fullscreen_changed=1;
+		  my_fade_out();
+		  set_resolution(d[13].d2,0,CONFIG_FULLSCREEN);
 		  break;
 		case 16:
+		  CONFIG_PAGE_FLIP=CONFIG_PAGE_FLIP ? 0 : 1;
+		  d[16].dp=get_page_flip_str();
+		  my_button_proc (MSG_DRAW,d+16,0);
+		  break;
+		case 17:
+		  CONFIG_WAVE_ON=CONFIG_WAVE_ON ? 0 : 1;
+		  d[17].dp=get_wave_mode_str();
+		  my_button_proc (MSG_DRAW,d+17,0);
+		  break;
+		case 18:
 		  retour=wave_options();
 		  display_back_image();
 		  break;
