@@ -74,10 +74,10 @@ int init_all ()
  #ifdef ALLEGRO_DOS
  set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
  #endif
- log_println_str ("Starting Allegro by Shawn Hargreaves.");
+ log_println_str ("Starting Allegro (http://www.talula.demon.co.uk/allegro)");
  log_println();
- log_print_str("Platform : ");
- log_println_str(ALLEGRO_PLATFORM_STR);
+ log_print_str("Allegro ID : ");
+ log_println_str(allegro_id);
  log_println();
  
  set_startup();
@@ -131,7 +131,7 @@ int start_graphic (void)
 {
  int retour;
 
- retour= (!set_resolution (CONFIG_GFX_MENU,0));
+ retour= (!set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN));
 
  return retour;
 }
