@@ -71,6 +71,7 @@ int my_initialise_joystick (void)
 
 	if (STARTUP_JOYSTICK_ON)
     {
+#ifdef joy_type
      switch (CONFIG_JOYSTICK_ON)
         {
          case 1: joy_type=JOY_TYPE0;
@@ -80,6 +81,7 @@ int my_initialise_joystick (void)
          case 3: joy_type=JOY_TYPE2;
                  break;
         }
+#endif
      return initialise_joystick ();
     }
  else
