@@ -34,6 +34,8 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <stdio.h>
+
 #include "alleg2.h"
 #include "bigdata.h"
 #include "disk.h"
@@ -309,6 +311,8 @@ void *archive_raw_map (const char *filename)
   char *temp=NULL,*result=NULL;
   short *ptr_wh;
   int *ptr_bg;
+  char readable_name_buffer[LW_MAP_READABLE_NAME_SIZE+1];
+  static int index=1;
 
   bmp=load_bitmap (filename,pal);
   if (bmp)
@@ -332,15 +336,30 @@ void *archive_raw_map (const char *filename)
 
   if (temp)
     {
-      result=malloc (size+8);
+      result=malloc (size+8+LW_MAP_READABLE_NAME_SIZE);
       if (result)
         {
+	  /*
+	   * The first step is to store the size of the map
+	   */
 	  ptr_bg=(void *) ptr_wh=(void *) result;
 	  ptr_bg[0]=bg_size;
 	  ptr_wh[2]=w;
 	  ptr_wh[3]=h;
+
+	  /*
+	   * Then we store its name
+	   */
+	  memset(readable_name_buffer,0,sizeof(readable_name_buffer));
+	  sprintf(readable_name_buffer,"Custom map %d",index++);
+	  memcpy(result+8,readable_name_buffer,
+		 LW_MAP_READABLE_NAME_SIZE);;
+
+	  /*
+	   * And at last we write the map itself
+	   */
 	  for (i=0;i<size;++i)
-	    result[i+8]=temp[i];
+	    result[i+8+LW_MAP_READABLE_NAME_SIZE]=temp[i];
         }
       free_last_big_data_bottom ();
     }
@@ -349,13 +368,9 @@ void *archive_raw_map (const char *filename)
 }
 
 /*------------------------------------------------------------------*/
-BITMAP *create_bicolor_map (int num, int fg, int bg)
+static void *get_map_safe(int num)
 {
-  int   pos_dst,pos_src,w,h,i,l,color;
-  signed char *data_dst,*data_src;
-  short *data2;
-  BITMAP *result;
-  void *raw_map;
+  void *raw_map=NULL;
 
   if (num>RAW_MAP_NUMBER-1)
     num=RAW_MAP_NUMBER-1;
@@ -368,9 +383,25 @@ BITMAP *create_bicolor_map (int num, int fg, int bg)
   else
     raw_map=RAW_MAP_ORDERED[num];
 
+  return raw_map;
+}
+
+/*------------------------------------------------------------------*/
+BITMAP *create_bicolor_map (int num, int fg, int bg)
+{
+  int   pos_dst,pos_src,w,h,i,l,color;
+  signed char *data_dst,*data_src;
+  short *data2;
+  BITMAP *result;
+  void *raw_map;
+
+  raw_map=get_map_safe(num);
+
   data_src=raw_map;
   data2=raw_map;
-  data_src+=8;
+
+  data_src+=8+LW_MAP_READABLE_NAME_SIZE;
+
   w=data2[2];
   h=data2[3];
 
@@ -440,4 +471,36 @@ BITMAP *create_textured_map (int num, int fg, int bg)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+char *get_map_readable_name (int num)
+{
+  static char result[LW_MAP_READABLE_NAME_SIZE+1];
+  void *raw_map;
+  char *char_ptr;
+
+  raw_map=get_map_safe(num);
+  char_ptr=(char *) raw_map;
+
+  memcpy(result,char_ptr+8,LW_MAP_READABLE_NAME_SIZE);
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+void get_map_res (int num,int *w,int *h)
+{
+  void *raw_map;
+  short *res_ptr;
+  short res_w,res_h;
+
+  raw_map=get_map_safe(num);
+  res_ptr=(short *) raw_map;
+
+  res_w=res_ptr[2];
+  res_h=res_ptr[3];
+
+  *w=res_w;
+  *h=res_h;
+}
+
 
