@@ -137,7 +137,9 @@ int play_sequence (void)
       * actually different from the menu resolution
       */
      if (need_to_change_mode(CONFIG_GFX_GAME,CONFIG_GFX_MENU,CONFIG_PAGE_FLIP))
-		result=set_resolution (CONFIG_GFX_GAME,CONFIG_PAGE_FLIP);
+		result=set_resolution (CONFIG_GFX_GAME,
+				CONFIG_PAGE_FLIP,
+				CONFIG_FULLSCREEN);
 
      /*
       * the blank round function initializes the double-buffer system
@@ -179,7 +181,7 @@ int play_sequence (void)
       * again, we change the video mode only if it is really required
       */
      if (need_to_change_mode(CONFIG_GFX_GAME,CONFIG_GFX_MENU,CONFIG_PAGE_FLIP))
-		result=set_resolution (CONFIG_GFX_MENU,0);
+		result=set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN);
 
      /*
       * displays the 3 tubes with the score
