@@ -151,9 +151,12 @@ int lw_sock_recv_buffer(int sock, char *buffer, int len)
   limit_ticker=get_ticker()+LW_SOCK2CLI_TIMEOUT_MSEC;
   while (limit_ticker>get_ticker() && !result)
     {
-      if (lw_sock_recv_buffer_ex(sock,buffer,len))
+      if (lw_sock_peek_ex(sock,len))
 	{
-	  result=1;
+	  if (lw_sock_recv_buffer_ex(sock,buffer,len))
+	    {
+	      result=1;
+	    }
 	}
     }
 
