@@ -67,7 +67,11 @@
 
 #define STARTUP_MAX_PATH_LENGTH           1000
 
+#ifdef ALLEGRO_DOS
 int STARTUP_BIG_DATA=8192;
+#else
+int STARTUP_BIG_DATA=16384;
+#endif
 int STARTUP_DIGI_CARD=DIGI_AUTODETECT;
 int STARTUP_JOYSTICK_ON=1;
 int STARTUP_BACK_STATE=1;
@@ -94,13 +98,9 @@ int STARTUP_CHECK=0;
 #endif
 
 char STARTUP_CFG_PATH[STARTUP_MAX_PATH_LENGTH];
-//char *STARTUP_CFG_PATH="data\\lw.cfg";
 char STARTUP_DAT_PATH[STARTUP_MAX_PATH_LENGTH];
-//char *STARTUP_DAT_PATH="data\\lw.dat";
 char STARTUP_MAP_PATH[STARTUP_MAX_PATH_LENGTH];
-//char *STARTUP_MAP_PATH="custom\\map\\";
 char STARTUP_TEX_PATH[STARTUP_MAX_PATH_LENGTH];
-//char *STARTUP_TEX_PATH="custom\\texture\\";
 
 /*==================================================================*/
 /* fonctions                                                        */
